## Palette

Open the Palette sidebar with the sidebar button  in the top-right corner of the window, or choose “Window” → “Palette” (Cmd-Opt-P).
Glyphs includes four sections: “Dimensions”, “Fit Curve”, “Layers”, and “Transformations”.
Plug-ins can add additional sections to the Palette.
Collapse or expand a section by clicking the chevron on the left side of the section name.